aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal/include/io_channel.h
diff options
context:
space:
mode:
Diffstat (limited to 'os/hal/include/io_channel.h')
-rw-r--r--os/hal/include/io_channel.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/os/hal/include/io_channel.h b/os/hal/include/io_channel.h
index af90b431e..b0c21a9ee 100644
--- a/os/hal/include/io_channel.h
+++ b/os/hal/include/io_channel.h
@@ -230,7 +230,7 @@ typedef struct {
#define _base_asynchronous_channel_data \
_base_channel_data \
/* I/O condition event source.*/ \
- EventSource event;
+ event_source_t event;
/**
* @extends BaseChannelVMT
@@ -264,11 +264,11 @@ typedef struct {
*
* @param[in] ip pointer to a @p BaseAsynchronousChannel or derived
* class
* @return A pointer to an @p EventSource object.
*
* @api
*/
-#define chnGetEventSource(ip) (&((ip)->event))
+#define chnGetevent_source_t(ip) (&((ip)->event))
/**
* @brief Adds status flags to the listeners's flags mask.
@@ -264,11 +264,11 @@ typedef struct {
* @param[in] ip pointer to a @p BaseAsynchronousChannel or derived
* class
- * @return A pointer to an @p EventSource object.
+ * @return A pointer to an @p event_source_t object.
*
* @api